#
# spec file for package grafana
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define GRAFANA_USER    %{name}
%define GRAFANA_GROUP   %{name}
%define GRAFANA_HOME    %{_datadir}/%{name}

#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           grafana
Version:        6.0.1
Release:        6.2
Summary:        Dashboards and editors for Graphite, InfluxDB, OpenTSDB
License:        Apache-2.0
Group:          System/Monitoring
Url:            http://grafana.org/
Source:         %{name}-%{version}.tar.xz
Source1:        %{name}-rpmlintrc
# Instructions on the build process
Source2:        README
# Makefile to automate build process
Source3:        Makefile
Requires:       phantomjs
# Needed as a BuildRequires too, so setting up a symlink will work
BuildRequires:  fdupes
BuildRequires:  go >= 1.11
BuildRequires:  golang-packaging
BuildRequires:  libgcc_s1
BuildRequires:  phantomjs
BuildRequires:  shadow
Requires(post): %insserv_prereq
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}

%description
A graph and dashboard builder for visualizing time series metrics.

Grafana provides ways to create, explore, and share
dashboards and data with teams.

%prep
%setup -q -n grafana-%{version}

%build
%goprep github.com/grafana/grafana
# Manual build in order to inject ldflags so grafana correctly displays
# the version in the footer of each page.  Note that we're only injecting
# main.version, not main.commit or main.buildstamp as is done in the upstream
# build.go, because we don't have access to the git commit history here.
# (The %%gobuild macro can't take quoted strings; they get split up when
# expanded to $extra_flags in process_build() in /usr/lib/rpm/golang.sh.)
export IMPORTPATH="github.com/grafana/grafana"
export BUILDFLAGS="-v -p 4 -x -buildmode=pie"
export GOPATH=%{_builddir}/go:%{_builddir}/contrib
export GOBIN=%{_builddir}/go/bin
go install $BUILDFLAGS -ldflags '-X main.version=%{version}' $IMPORTPATH/pkg/cmd/...

%install
%goinstall

# we're missing %%gosrc and %%gofilelist... (although that *might* be ok...)

install -Dm644 {packaging/rpm/systemd/,%{buildroot}%{_unitdir}/}%{name}-server.service
install -dm755 %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service  %{buildroot}%{_sbindir}/rc%{name}-server
mv %{buildroot}/%{_bindir}/grafana-* %{buildroot}/%{_sbindir}

install -Dm644 packaging/rpm/sysconfig/%{name}-server \
%{buildroot}%{_fillupdir}/sysconfig.%{name}-server

install -d -m0750 %{buildroot}%{_localstatedir}/lib/%{name}
install -d -m0750 %{buildroot}%{_localstatedir}/log/%{name}
install -d -m0755 %{buildroot}/%{_localstatedir}/lib/%{name}/plugins
install -d -m0755 %{buildroot}/%{_localstatedir}/lib/%{name}/dashboards
install -d -m0755 %{buildroot}%{_sysconfdir}/%{name}/provisioning/dashboards

install -Dm640 conf/sample.ini %{buildroot}%{_sysconfdir}/%{name}/%{name}.ini
install -Dm640 {conf/,%{buildroot}%{_sysconfdir}/%{name}/}ldap.toml
install -Dm644 {conf/,%{buildroot}%{_datadir}/%{name}/conf/}defaults.ini
install -m644 {conf/,%{buildroot}%{_datadir}/%{name}/conf/}sample.ini
install -Dm644 {conf/provisioning/dashboards/,%{buildroot}%{_datadir}/%{name}/conf/provisioning/dashboards/}sample.yaml
install -Dm644 {conf/provisioning/datasources/,%{buildroot}%{_datadir}/%{name}/conf/provisioning/datasources/}sample.yaml
cp -pr public %{buildroot}%{_datadir}/%{name}/
install -d -m755 %{buildroot}%{_datadir}/%{name}/vendor
install -d -m755 %{buildroot}%{_datadir}/%{name}/tools
# phantomjs is used for rendering PNG images of graphs.  The frontend asset
# build process downloadsa prebuilt x86_64 binary, which ends up in
# vendor/phantomjs/phantomjs.  This is ugly but works for x86_64.  It naturally
# will not work for other architectures, so instead we remove the phantomjs
# binary and install a symlink to the systemwide /usr/bin/phantomjs.
cp -pr tools/phantomjs %{buildroot}%{_datadir}/%{name}/tools/
rm -f %{buildroot}%{_datadir}/%{name}/tools/phantomjs/phantomjs
ln -s %{_bindir}/phantomjs %{buildroot}%{_datadir}/%{name}/tools/phantomjs/phantomjs

# Do *not* use %%fudpes -s -- this will result in grafana failing to load
# all the plugins (something in the plugin scanner can't cope with files
# in there being symlinks).
%fdupes %{buildroot}/%{_datadir}

%check
#gotest github.com/grafana/grafana/pkg...

%pre
%service_add_pre %{name}-server.service

echo "Creating user %{GRAFANA_USER} and group %{GRAFANA_GROUP} if not present"
getent group %{GRAFANA_GROUP} > /dev/null || groupadd -r %{GRAFANA_GROUP}
getent passwd %{GRAFANA_GROUP} > /dev/null || useradd -r -g %{GRAFANA_GROUP} \
-d %{GRAFANA_HOME} -s /sbin/nologin -c "%{GRAFANA_USER} user" %{GRAFANA_GROUP}

%post
%{fillup_only -n %{name}-server}
%service_add_post %{name}-server.service

%preun
%service_del_preun %{name}-server.service

%postun
%service_del_postun %{name}-server.service

%files
%defattr(-,root,root)
%doc CHANGELOG* LICENSE*
%{_sbindir}/%{name}*
%{_sbindir}/rc%{name}-server
%{_unitdir}/%{name}-server.service
%{_fillupdir}/sysconfig.%{name}-server
%attr(0750,root,%{GRAFANA_GROUP}) %dir %{_sysconfdir}/%{name}
%attr(0750,root,%{GRAFANA_GROUP}) %dir %{_sysconfdir}/%{name}/provisioning
%attr(0750,root,%{GRAFANA_GROUP}) %dir %{_sysconfdir}/%{name}/provisioning/dashboards
%attr(0750,root,%{GRAFANA_GROUP}) %dir %{_datadir}/%{name}/conf
%attr(0640,root,%{GRAFANA_GROUP}) %config(noreplace) %{_sysconfdir}/%{name}/%{name}.ini
%attr(0640,root,%{GRAFANA_GROUP}) %config(noreplace) %{_sysconfdir}/%{name}/ldap.toml
%attr(0750,%{GRAFANA_USER},%{GRAFANA_GROUP}) %dir %{_localstatedir}/lib/%{name}
%attr(0750,%{GRAFANA_USER},%{GRAFANA_GROUP}) %dir %{_localstatedir}/lib/%{name}/plugins
%attr(0750,%{GRAFANA_USER},%{GRAFANA_GROUP}) %dir %{_localstatedir}/lib/%{name}/dashboards
%attr(0750,%{GRAFANA_USER},%{GRAFANA_GROUP}) %dir %{_localstatedir}/log/%{name}
%doc %{_datadir}/%{name}/conf/sample.ini
%doc %{_datadir}/%{name}/conf/provisioning/dashboards/sample.yaml
%doc %{_datadir}/%{name}/conf/provisioning/datasources/sample.yaml
%config %{_datadir}/%{name}/conf/defaults.ini
%{_datadir}/%{name}

%changelog
* Mon Mar 11 2019 jan.fajerski@suse.com
- Update to version 6.0.1:
  * Bug Fixes:
    + utils: show string errors
    + Viewers with viewers_can_edit should be able to access /explore
    +  log phantomjs output even if it timeout and include orgId when render alert
- Update to version 6.0.0:
  * Breaking Changes:
    + Text Panel: The text panel does no longer by default allow unsantizied
    HTML. This means that if you have text panels with scripts tags they will no
    longer work as before. To enable unsafe javascript execution in text panels
    enable the settings disable_sanitize_html under the section [panels] in your
    Grafana ini file, or set env variable GF_PANELS_DISABLE_SANITIZE_HTML=true.
    + Dashboard: Panel property minSpan replaced by maxPerRow. Dashboard
    migration will automatically migrate all dashboard panels using the minSpan
    property to the new maxPerRow property
    + Internal Metrics Edition has been added to the build_info metric. This will break any Graphite queries using this metric. Edition will be a new label for the Prometheus metric.
  * New Features:
    + Alerting: Adds support for Google Hangouts Chat notifications
    + Elasticsearch: Support bucket script pipeline aggregations
    + Influxdb: Add support for time zone (tz) clause
    + Snapshots: Enable deletion of public snapshot
    + Provisioning: Provisioning support for alert notifiers
    + Explore: A whole new way to do ad-hoc metric queries and exploration. Split view in half and compare metrics & logs and much much more. Read more here
    + Auth: Replace remember me cookie solution for Grafana's builtin, LDAP and OAuth authentication with a solution based on short-lived tokens
    + AzureMonitor: Enable alerting by converting Azure Monitor API to Go
    + Explore A new query focused workflow for ad-hoc data exploration and troubleshooting.
    + Grafana Loki Integration with the new open source log aggregation system from Grafana Labs.
    + Gauge Panel A new standalone panel for gauges.
    + New Panel Editor UX improves panel editing and enables easy switching between different visualizations.
    + Google Stackdriver Datasource is out of beta and is officially released.
    + React Plugin support enables an easier way to build plugins.
    + Named Colors in our new improved color picker.
    + Removal of user session storage makes Grafana easier to deploy & improves security.
  * Bug Fixes:
    + Metrics: Fixes broken usagestats metrics for /metrics
    + Dashboard: Fixes kiosk mode should have &kiosk appended to the url
    + Dashboard: Fixes kiosk=tv mode with autofitpanels should respect header
    + Image rendering: Fixed image rendering issue for dashboards with auto refresh,
    + Dashboard: Fix only users that can edit a dashboard should be able to update panel json.
    + LDAP: fix allow anonymous initial bind for ldap search.
    + UX: Fixed scrollbar not visible initially (only after manual scroll).
    + Datasource admin TestData
    + Dashboard: Fixed scrolling issue that caused scroll to be locked to bottom.
    + Explore: Viewers with viewers_can_edit should be able to access /explore.
    + Security fix: limit access to org admin and alerting pages.
    + Panel Edit minInterval changes did not persist
    + Teams: Fixed bug when getting teams for user.
    + Stackdriver: fix for float64 bounds for distribution metrics
    + Stackdriver: no reducers available for distribution type
    + Influxdb: Add support for alerting on InfluxDB queries that use the non_negative_difference function
    + Alerting: Fix percent_diff calculation when points are nulls
    + Alerting: Fixed handling of alert urls with true flags
    + Gauge: Fix issue with gauge requests being cancelled
    + Gauge: Accept decimal inputs for thresholds
    + UI: Fix error caused by named colors that are not part of named colors palette
    + Search: Bug pressing special regexp chars in input fields
    + Permissions: No need to have edit permissions to be able to "Save as"
    + Search: Fix for issue with scrolling the "tags filter" dropdown
    + Prometheus: Query for annotation always uses 60s step regardless of dashboard range
    + Annotations: Fix creating annotation when graph panel has no data points position the popup outside viewport
    + Piechart/Flot: Fixes multiple piechart instances with donut bug
    + plus many minor changes and fixes
- Update to version 5.4.3:
  * Fixes:
    + Alerting Invalid frequency causes division by zero in alert scheduler
    + Dashboard Dashboard links do not update when time range changes
    + Limits Support more than 1000 datasources per org
    + Backend fix signed in user for orgId=0 result should return active org id
    + Provisioning Adds orgId to user dto for provisioned dashboards
- Update to version 5.4.2:
  * Fixes:
    + Datasource admin: Fix for issue creating new data source when same name exists
    + OAuth: Fix for oauth auto login setting, can now be set using env variable
    + Dashboard search: Fix for searching tags in tags filter dropdown.
- Update to version 5.4.1:
  * Fixes:
    + Stackdriver: Fixes issue with data proxy and Authorization header
    + Units: fixedUnit for Flow:l/min and mL/min
    + Logging: Fix for issue where data proxy logged a secret when debug logging was enabled, now redacted.
    + InfluxDB: Add support for alerting on InfluxDB queries that use the cumulative_sum function.
    + Plugins: Panel plugins should no receive the panel-initialized event again as usual.
    + Embedded Graphs: Iframe graph panels should now work as usual.
    + Postgres: Improve PostgreSQL Query Editor if using different Schemas,
    + Quotas: Fixed for updating org & user quotas.
    + Cloudwatch: Add the AWS/SES Cloudwatch metrics of BounceRate and ComplaintRate to auto complete list.
    + Dashboard Search: Fixed filtering by tag issues.
    + Graph: Fixed time region issues,
    + Graph: Fixed issue with series color picker popover being placed outside window.
- Update to version 5.4.0:
  * Breaking Changes:
    + Postgres/MySQL/MSSQL datasources now per default uses max open connections = unlimited (earlier 10), max idle connections = 2 (earlier 10) and connection max lifetime = 4 hours (earlier unlimited).
  * Features:
    + Alerting: Introduce alert debouncing with the FOR setting.
    + Alerting: Option to disable OK alert notifications
    + Postgres/MySQL/MSSQL: Adds support for configuration of max open/idle connections and connection max lifetime. Also, panels with multiple SQL queries will now be executed concurrently
    + MySQL: Graphical query builder
    + MySQL: Support connecting thru Unix socket for MySQL datasource
    + MSSQL: Add encrypt setting to allow configuration of how data sent between client and server are encrypted
    + Stackdriver: Not possible to authenticate using GCE metadata server
    + Teams: Team preferences (theme, home dashboard, timezone) support
    + Graph: Time regions support enabling highlight of weekdays and/or certain timespans
    + OAuth: Automatic redirect to sign-in with OAuth
    + Stackdriver: Template query editor
  * Fixes:
    + Cloudwatch: Fix invalid time range causes segmentation fault
    + Cloudwatch: AWS/CodeBuild metrics and dimensions
    + MySQL: Fix $__timeFrom() and $__timeTo() should respect local time zone
    + Graph: Fix legend always visible even if configured to be hidden
    + Elasticsearch: Fix regression when using datasource version 6.0+ and alerting
- Update to version 5.3.4:
  * minor bug fixes
- Update to version 5.3.3:
  * fix potential security issue https://community.grafana.com/t/grafana-5-3-3-and-4-6-5-security-update/11961
* Tue Jan  8 2019 witold.bedyk@suse.com
- Provide default dashboard provider from upstream
* Mon Oct 29 2018 moio@suse.com
- Update to version 5.3.2
  * InfluxDB/Graphite/Postgres: Prevent cross site scripting (XSS) in query editor
  * Postgres: Fix template variables error
  * Cloudwatch: Fix service panic because of race conditions
  * Cloudwatch: Fix check for invalid percentile statistics
  * Stackdriver/Cloudwatch: Allow user to change unit in graph panel if cloudwatch/stackdriver datasource response doesn't include unit
  * Stackdriver: stackdriver user-metrics duplicated response when multiple resource types
  * Variables: Fix text box template variable doesn't work properly without a default value
  * Variables: Fix variable dependency check when using ${var} format
  * Dashboard: Fix kiosk=1 url parameter should put dashboard in kiosk mode
  * LDAP: Fix super admins can also be admins of orgs
  * Provisioning: Fix deleting provisioned dashboard folder should cleanup provisioning meta data
  * Docker: adds curl back into the docker image for utility
- Update to version 5.3.1
  * Render: Fix PhantomJS render of graph panel when legend displayed as table to the right
  * Stackdriver: Filter option disappears after removing initial filter
  * Elasticsearch: Fix no limit size in terms aggregation for alerting queries
  * InfluxDB: Fix for annotation issue that caused text to be shown twice
  * Variables: Fix nesting variables leads to exception and missing refresh
  * Variables: Prometheus: Single letter labels are not supported
  * Graph: Fix graph time formatting for Last 24h ranges
  * Playlist: Fix cannot add dashboards with long names to playlist
  * HTTP API: Fix /api/org/users so that query and limit querystrings works
- Update to version 5.3.0
  * Stackdriver: Filter wildcards and regex matching are not yet supported
  * Stackdriver: Support the distribution metric type for heatmaps
  * Cloudwatch: Automatically set graph yaxis unit
- Update to version 5.3.0-beta3
  * Stackdriver: Fix for missing ngInject
  * Permissions: Fix for broken permissions selector
  * Alerting: Alert reminders deduping not working as expected when running multiple Grafana instances
- Update to version 5.3.0-beta2
  + New Features
  * Annotations: Enable template variables in tagged annotations queries
  * Stackdriver: Support for Google Stackdriver Datasource
  + Minor
  * Provisioning: Dashboard Provisioning now support symlinks that changes target
  * OAuth: Allow oauth email attribute name to be configurable
  * Tags: Default sort order for GetDashboardTags
  * Prometheus: Label completion queries respect dashboard time range
  * Prometheus: Allow to display annotations based on Prometheus series value
  * Prometheus: Adhoc-filtering for Prometheus dashboards
  * Singlestat: Fix gauge display accuracy for percents
  * Dashboard: Prevent auto refresh from starting when loading dashboard with absolute time range
  * Templating: New templating variable type Text box that allows free text input
  * Alerting: Link to view full size image in Microsoft Teams alert notifier
  * Alerting: Fixes a bug where all alerts would send reminders after upgrade & restart
  * Alerting: Concurrent render limit for graphs used in notifications
  * Postgres/MySQL/MSSQL: Add support for replacing $__interval and  $__interval_ms in alert queries
- Update to version 5.3.0-beta1
  + New Major Features
  * Alerting: Notification reminders
  * Dashboard: TV & Kiosk mode changes, new cycle view mode button in dashboard toolbar
  * OAuth: Gitlab OAuth with support for filter by groups
  * Postgres: Graphical query builder
  + New Features
  * LDAP: Define Grafana Admin permission in ldap group mappings, PR
  * LDAP: Client certificates support
  * Profile: List teams that the user is member of in current/active organization
  * Configuration: Allow auto-assigning users to specific organization (other than Main. Org) and
  * Dataproxy: Pass configured/auth headers to a Datasource
  * CloudWatch: GetMetricData support
  * Postgres: TimescaleDB support, e.g. use time_bucket for grouping by time when option enabled
  * Cleanup: Make temp file time to live configurable
  + Minor
  * Alerting: Its now possible to configure the default value for how to handle errors and no data in alerting
  * Alerting: Fix diff and percent_diff reducers
  * Alerting: Fix rendering timeout which could cause notifications to not be sent due to rendering timing out
  * Docker: Make it possible to set a specific plugin url
  * GrafanaCli: Fixed issue with grafana-cli install plugin resulting in corrupt http response from source error
  * Provisioning: Should allow one default datasource per organisation
  * Github OAuth: Allow changes of user info at Github to be synched to Grafana when signing in
  * OAuth: Fix overriding tls_skip_verify_insecure using environment variable
  * Prometheus: Fix graph panel bar width issue in aligned prometheus queries
  * Prometheus: Heatmap - fix unhandled error when some points are missing
  * Prometheus: Add $__interval, $__interval_ms, $__range, $__range_s & $__range_ms support for dashboard and template queries
  * Elasticsearch: For alerting/backend, support having index name to the right of pattern in index pattern
  * Graphite: Fix for quoting of int function parameters (when using variables)
  * InfluxDB: Support timeFilter in query templating for InfluxDB
  * Postgres/MySQL/MSSQL: New $__unixEpochGroup and $__unixEpochGroupAlias macros
  * Postgres/MySQL/MSSQL: Add previous fill mode to $__timeGroup macro which will fill in previously seen value when point is missing
  * Postgres/MySQL/MSSQL: Use floor rounding in $__timeGroup macro function
  * Postgres/MySQL/MSSQL: Use metric column as prefix when returning multiple value columns
  * Postgres/MySQL/MSSQL: New $__timeGroupAlias macro. Postgres $__timeGroup no longer automatically adds time column alias
  * Postgres/MySQL/MSSQL: Escape single quotes in variables
  * Postgres/MySQL/MSSQL: Min time interval support
  * MySQL/MSSQL: Use datetime format instead of epoch for $__timeFilter, $__timeFrom and $__timeTo macros
  * Postgres: Escape ssl mode parameter in connectionstring
  * Cloudwatch: Improved error handling
  * Cloudwatch: AppSync metrics and dimensions
  * Cloudwatch: Direct Connect metrics and dimensions
  * Cloudwatch: Added BurstBalance metric to list of AWS RDS metrics
  * Cloudwatch: Add new Redshift metrics and dimensions
  * Dashboard: Fix selecting current dashboard from search should not reload dashboard
  * Dashboard: Use uid when linking to dashboards internally in a dashboard
  * Graph: Option to hide series from tooltip
  * Singlestat: Make colorization of prefix and postfix optional in singlestat
  * Table: Adjust header contrast for the light theme
  * Table: Fix link color when using light theme and thresholds in use
  * Table: Fix for useless horizontal scrollbar for table panel
  * Table: Make table sorting stable when null values exist
  * Heatmap: Fix broken tooltip and crosshair on Firefox
  * Datasource: Fix UI issue with secret fields after updating datasource
  * Variables: Skip unneeded extra query request when de-selecting variable values used for repeated panels
  * Variables: Limit amount of queries executed when updating variable that other variable(s) are dependent on
  * Variables: Support query variable refresh when another variable referenced in Regex field change its value
  * Variables: Support variables in query variable Custom all value field
  * Units: Change units to include characters for power of 2 and 3
  * Units: Polish złoty currency
  * Units: Adds bitcoin axes unit
  * Api: Delete nonexistent datasource should return 404
  * Logging: Reopen log files after receiving a SIGHUP signal
  * Login: Show loading animation while waiting for authentication response on login
  * UI: Fix iOS home screen "app" icon and Windows 10 app experience
  * Plugins: Convert URL-like text to links in plugins readme
    + Breaking changes
  * Postgres datasource no longer automatically adds time column alias when using the $__timeGroup alias. However, there's code in place which should make this change backward compatible and shouldn't create any issues
  * Kiosk mode now also hides submenu (variables)
  * ?inactive url parameter no longer supported, replaced with kiosk=tv url parameter
  + New experimental features
  * Dashboard: Auto fit dashboard panels to optimize space used for current TV / Monitor
  + Tech
  * Frontend: Convert all Frontend Karma tests to Jest tests
  * Backend: Upgrade to golang 1.11
- Update to version 5.2.4
  * GrafanaCli: Fixed issue with grafana-cli install plugin resulting in corrupt http response from source error
- Update to version 5.2.3
  * Important fix for LDAP & OAuth login vulnerability
- Update to version 5.2.2
  * Prometheus: Fix graph panel bar width issue in aligned prometheus queries
  * Dashboard: Dashboard links not updated when changing variables
  * Postgres/MySQL/MSSQL: Fix connection leak
  * Plugins: Fix loading of external plugins
  * Dashboard: Remove unwanted scrollbars in embedded panels
  * Prometheus: Prevent error using $__interval_ms in query
- Update to version 5.2.1
  * Auth Proxy: Important security fix for whitelist of IP address feature
  * UI: Fix - Grafana footer overlapping page
  * Logging: Errors should be reported before crashing
- Update to version 5.2.0-stable
  * Plugins: Handle errors correctly when loading datasource plugin thx
  * Render: Enhance error message if phantomjs executable is not found
  * Dashboard: Set correct text in drop down when variable is present in url
  * LDAP: Handle "dn" ldap attribute more gracefully
- Update to version 5.2.0-beta3
  * Build: All rpm packages should be signed
- Update to version 5.2.0-beta2
  + New Features
  * Dashboard: Import dashboard to folder
  + Minor
  * Permissions: Important security fix for API keys with viewer role
  * Dashboard: Fix so panel titles doesn't wrap
  * Dashboard: Prevent double-click when saving dashboard
  * Dashboard: AutoFocus the add-panel search filter thx
  * Units: W/m2 (energy), l/h (flow) and kPa (pressure)
  * Units: Litre/min (flow) and milliLitre/min (flow)
  * Alerting: Fix mobile notifications for Microsoft Teams alert notifier
  * Influxdb: Add support for mode function
  * Cloudwatch: Fixes panic caused by bad timerange settings
  * Auth Proxy: Whitelist proxy IP address instead of client IP address
  * User Management: Make sure that a user always has a current org assigned
  * Snapshots: Fix: annotations not properly extracted leading to incorrect rendering of annotations
  * LDAP: Allow use of DN in group_search_filter_user_attribute and member_of
  * Graph: Fix legend decimals precision calculation
  * Dashboard: Make sure to process panels in collapsed rows when exporting dashboard
  * Dashboard: Dashboard link doesn't work when "As dropdown" option is checked
  * Dashboard: Fix regressions after save modal changes, including adhoc template issues
  * Docker: Config keys ending with _FILE are not respected
- Update to version 5.2.0-beta1
  + New Features
  * Elasticsearch: Alerting support
  * Build: Crosscompile and packages Grafana on arm, windows, linux and darwin
  * Login: Change admin password after first login
  * Alert list panel: Updated to support filtering alerts by name, dashboard title, folder, tags
  + Minor
  * Dashboard: Modified time range and variables are now not saved by default
  * Graph: Show invisible highest value bucket in histogram
  * Dashboard: Enable "Save As..." if user has edit permission
  * Prometheus: Query dates are now step-aligned
  * Prometheus: Table columns order now changes when rearrange queries
  * Variables: Fix variable interpolation when using multiple formatting types
  * Dashboard: Fix date selector styling for dark/light theme in time picker control
  * Discord: Alert notification channel type for Discord
  * InfluxDB: Support SELECT queries in templating query
  * InfluxDB: Support count distinct aggregation
  * Dashboard: JSON Model under dashboard settings can now be updated & changes saved
  * Security: Fix XSS vulnerabilities in dashboard links
  * Singlestat: Fix "time of last point" shows local time when dashboard timezone set to UTC
  * Prometheus: Add support for passing timeout parameter to Prometheus
  * Login: Add optional option sign out url for generic oauth
  * Login: Use proxy server from environment variable if available
  * Invite users: Friendlier error message when smtp is not configured
  * Graphite: Don't send distributed tracing headers when using direct/browser access mode
  * Sidenav: Show create dashboard link for viewers if at least editor in one folder
  * SQL: Second epochs are now correctly converted to ms
  * Singlestat: Fix singlestat threshold tooltip
  * Dashboard: Hide grid controls in fullscreen/low-activity views
  * Dashboard: Validate uid when importing dashboards
  * Docker: Support for env variables ending with _FILE
  * Alert list panel: Show alerts for user with viewer role
  * Provisioning: Verify checksum of dashboards before updating to reduce load on database
  * Provisioning: Support symlinked files in dashboard provisioning config files
  * Dashboard list panel: Search dashboards by folder
  * Sidenav: Always show server admin link in sidenav if grafana admin
- Update to version 5.1.5
  * Docker: Config keys ending with _FILE are not respected
- Update to version 5.1.4
  * Permissions: Important security fix for API keys with viewer role
* Sat Jun 16 2018 opensuse-packaging@opensuse.org
- Update to version 5.1.3:
  * Heatmap support for Prometheus
  * Align Zero-Line for Right and Left Y-axes
  * allow setting the database
  * MSSQL Data Source
  * support multiple histogram series
  * support cloudwatch high resolution query
  * Added radiation units
  * Modify Grafana Pagerduty notifier to use Pagerduty API V2
  * prometheus editor: variable autocomplete support
  * Use net.SplitHostPort to support IPv6
  * See /usr/share/doc/packages/grafana/CHANGELOG.md for more details
* Sat Jun 16 2018 mc@suse.com
- remove unknown build flag -s
* Sat May  5 2018 dmueller@suse.com
- fix build for older distributions
* Wed Mar  7 2018 jengelh@inai.de
- Remove marketing wording from description.
* Wed Mar  7 2018 jan.fajerski@suse.com
- add user and group according to packaging guidelines
- add README and Makefile as Sources
* Thu Mar  1 2018 jfajerski@suse.com
- Update to version 5.0.0:
  + Github OAuth Fixed fetching github orgs from private github org
  + Provisioning Now handles deletes when dashboard json files removed from disk
  + Reset password Fixed problem with reset password form
  + Save dashboard Fixed issue with time range & variable reset after saving
  + Folders Make it easier/explicit to access/modify folders using the API
  + many more bugfixes
  + See /usr/share/doc/packages/grafana/CHANGELOG.md for more details
* Thu Feb  8 2018 jfajerski@suse.com
- Update to version 5.0.0beta1:
  + New Features:
  * Dashboard folders
  * Teams User groups (teams) implemented. Can be used in folder & dashboard permission list.
  * Dashboard grid: Panels are now layed out in a two dimensional grid (with x, y, w, h).
  * Templating: Vertical repeat direction for panel repeats.
  * UX: Major update to page header and navigation
  * Dashboard settings: Combine dashboard settings views into one with side menu
  * Alerting: Add support for internal image store
  * Data Source Proxy: Add support for whitelisting specified cookies that will be passed through to the data source when proxying data source requests
  * Text: Text panel are now edited in the ace editor
  * Teams: Add Microsoft Teams notifier
  * Datasources: Its now possible to configure datasources with config files
  * Graphite: Query editor updated to support new query by tag features
  * Dashboard history: New config file option versions_to_keep sets how many versions per dashboard to store
  * Dashboard as cfg: Load dashboards from file into Grafana on startup/change
  * Prometheus: Grafana can now send alerts to Prometheus Alertmanager while firing
  * Table: Support multiple table formated queries in table panel
  * Security: Protect against brute force (frequent) login attempts
  + Breaking Changes:
  * Persistent dashboard url's: New url's for dashboards that allows renaming dashboards without breaking links
  * GET /api/alerts property dashboardUri renamed to url and is now the full url (that is including app sub url).
  + Many Bugfixes
  + See /usr/share/doc/packages/grafana/CHANGELOG.md for more details
  - ------------------------------------------------------------------
* Mon Jan 29 2018 jan.fajerski@suse.com
- Use %%{_fillupdir} for sysconfig file
* Wed Jan 24 2018 tserong@suse.com
- Remove non-standard-gid from rpmlintrc
* Thu Jan 18 2018 tserong@suse.com
- Use GRAFANA_GROUP macro in spec file instead of GROUP (which otherwise
  collides with the package group, resulting in incorrect file/directory
  ownership)
* Sat Nov 11 2017 kkaempf@suse.com
- mark %%{_datadir}/%%{name}/conf/defaults.ini as %%conf instead
  of %%doc, grafana-server won't start without this file.
* Tue Oct 24 2017 johannes.grassler@suse.com
- Create /var/lib/grafana/dashboards/
* Tue Oct 17 2017 johannes.grassler@suse.com
- Create plugin directory and clean up (create in %%install,
  add to %%files) handling of /var/lib/grafana/* and
  /var/log/grafana.
* Mon Sep 18 2017 tserong@suse.com
- Update to version 4.5.1:
  + New Features:
  * Table panel: Render cell values as links
  * Elasticsearch: Add ad hoc filters directly by clicking values
  * MySQL: New rich query editor with syntax highlighting
  * Prometheus: New rich query editor with syntax highlighting
  + Enhancements:
  * GitHub OAuth: Support for GitHub organizations with 100+ teams
  * Graphite: Calls to Graphite api /metrics/find now include time range
  * Graphite: Added new graphite 1.0 functions
  * Elasticsearch: Ad-hoc filters now use query phrase match filters
  + Breaking change:
  * InfluxDB/Elasticsearch: The panel & data source option named "Group by
    time interval" is now named "Min time interval" and does now always
    define a lower limit for the auto group by time.
  + Other changes:
  * InfluxDB: Change time range filter for absolute time ranges to be
    inclusive instead of exclusive
  * InfluxDB: Added paranthesis around tag filters in queries
  + Bug Fixes:
  - Modals: Maintain scroll position after opening/leaving modal
  - Templating: You cannot select data source variables as data source
    for other template variables
  - MySQL/Postgres: Fix for max_idle_conn option default which was wrongly
    set to zero which does not mean unlimited but means zero.
  + See /usr/share/doc/packages/grafana/CHANGELOG.md for more details
* Thu Jun 22 2017 jan.fajerski@suse.com
- Fix spec file to create and own /var/{lib,log}/grafana (bsc#1044933)
* Fri Jun 16 2017 tserong@suse.com
- Require phantomjs package at runtime instead of shipping prebuilt
  x86_64 phantomjs binary (bsc#1044444)
* Tue May  2 2017 tserong@suse.com
- Make %%fdupes create hardlinks, not symlinks (symlinks result in
  grafana not being able to load plugins, and the UI breaking)
* Fri Apr 28 2017 tserong@suse.com
- Moved build of frontend assets from RPM %%pre and %%posttrans to
  Makefile, so this piece of work can be done by the packager, rather
  than at installation time.
* Thu Mar 23 2017 thipp@suse.de
- Update to version 4.2.0
- Refactoring based on new packaging proposal
* Mon Sep  5 2016 avvissu@yandex.by
- Update to 3.1.1:
  * see: /usr/share/doc/packages/grafana/CHANGELOG.txt
* Wed Jun  1 2016 avvissu@yandex.by
- Update to 3.0.4:
  * see: /usr/share/doc/packages/grafana/CHANGELOG.txt
* Wed May 25 2016 avvissu@yandex.by
- Update to 3.0.3:
  * see: /usr/share/doc/packages/grafana/CHANGELOG.txt
* Tue May 17 2016 avvissu@yandex.by
- Update to 3.0.2
  * see: /usr/share/doc/packages/grafana/CHANGELOG.txt
- Enable dependency auto-generation
- Don't use npm install -g grunt-cli
- Spec file cleanup
* Fri Apr  1 2016 avvissu@yandex.by
- Add golang(github.com/tools/godep)
* Thu Mar 31 2016 avvissu@yandex.by
- Remove static libraries
* Tue Mar 29 2016 avvissu@yandex.by
- Add _service file to control the URL used by %%%% pre
* Tue Feb 23 2016 avvissu@yandex.ru
- Use BuildRequires when a development branch becomes stable
* Mon Jan 25 2016 avvissu@yandex.ru
- Fix buid error: don't use %%%%goinstall (golang-macros.rb is not
  stable)
* Tue Jan  5 2016 avvissu@yandex.ru
- Fix build error: change GOPATH
- Copy the vendor folder after installation of package
* Fri Dec 11 2015 avvissu@yandex.ru
- Update to 2.6.0:
  * see: /usr/share/doc/packages/grafana/CHANGELOG
- Create a new spec file for building RPM
* Fri May  8 2015 mrueckert@suse.de
- initial package
